from setuptools import setup, find_packages

setup(
    name='kaipy',
    version='1.1.0',
    description='Python software for CGS MAGE and other Kaiju models',
    author='Kaiju team',
    author_email='wiltbemj@ucar.edu',
    url='https://bitbucket.org/aplkaiju/kaipy/src/master/',
    packages=find_packages(),
    include_package_data=True,
    package_data={'kaipy': ['scripts/*', 'scripts/*/*'],
                  'kaipy.satcomp': ['sc_helio.json','sc_cdasws_strs.json'],
                  'kaipy.gamera': ['lfmG.X.txt', 'lfmG.Y.txt'],
                  'kaipy.raiju.waveModel': ['chorus_polynomial.txt'],
                  'kaipy.rcm': ['enchan.dat', 'dktable'],
                  'kaipy.rcm.wmutils': ['chorus_polynomial.txt'],
                  'kaipy.cmaps': ['cmDDiv.txt', 'cmMLT.txt']
                  },
    python_requires='>=3.9,<3.13',
    install_requires=[
        'alive_progress',
        'astropy',
        'cdasws',
        'configparser',
        'h5py',
        'jupyterlab',
        'matplotlib',
        'pandas',
        'progressbar',
        'pyspedas',
        'pytest',
        'slack_sdk',
        'spacepy',
        'sphinx-rtd-theme',
        'sunpy',
        'gfz-api-client',
        'supermag-api'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD 3-Clause',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ],
    entry_points={
        'console_scripts': [
            'ih2oh=kaipy.scripts.OHelio.ih2oh:main',
            'helioSatComp=kaipy.scripts.datamodel.helioSatComp:main',
            'msphParallelSatComp=kaipy.scripts.datamodel.msphParallelSatComp:main',
            'msphPbsSatComp=kaipy.scripts.datamodel.msphPbsSatComp:main',
            'msphSatComp=kaipy.scripts.datamodel.msphSatComp:main',
            'rbspSCcomp=kaipy.scripts.datamodel.rbspSCcomp:main',
            'rcm_rbsp_satcomp=kaipy.scripts.datamodel.rcm_rbsp_satcomp:main',
            'block_genmpiXDMF=kaipy.scripts.postproc.block_genmpiXDMF:main',
            'embiggen=kaipy.scripts.postproc.embiggen:main',
            'embiggenMIX=kaipy.scripts.postproc.embiggenMIX:main',
            'embiggenRCM=kaipy.scripts.postproc.embiggenRCM:main',
            'embiggenVOLT=kaipy.scripts.postproc.embiggenVOLT:main',
            'genmpiXDMF=kaipy.scripts.postproc.genmpiXDMF:main',
            'genXDMF=kaipy.scripts.postproc.genXDMF:main',
            'genXLine=kaipy.scripts.postproc.genXLine:main',
            'numSteps=kaipy.scripts.postproc.numSteps:main',
            'pitmerge=kaipy.scripts.postproc.pitmerge:main',
            'printResTimes=kaipy.scripts.postproc.printResTimes:main',
            'run_calcdb=kaipy.scripts.postproc.run_calcdb:main',
            'run_ground_deltaB_analysis=kaipy.scripts.postproc.run_ground_deltaB_analysis:main',
            'slimFL=kaipy.scripts.postproc.slimFL:main',
            'slimh5=kaipy.scripts.postproc.slimh5:main',
            'slimh5_classic=kaipy.scripts.postproc.slimh5_classic:main',
            'supermag_comparison=kaipy.scripts.postproc.supermag_comparison:main',
            'supermag_analysis=kaipy.scripts.postproc.supermag_analysis:main',
            'ut2mjd=kaipy.scripts.postproc.ut2mjd:main',
            'cda2wind=kaipy.scripts.preproc.cda2wind:main',
            'genLFM=kaipy.scripts.preproc.genLFM:main',
            'genRCM=kaipy.scripts.preproc.genRCM:main',
            'genRAIJU=kaipy.scripts.preproc.genRAIJU:main',
            'wsa2gamera=kaipy.scripts.preproc.wsa2gamera:main',
            'XMLGenerator=kaipy.scripts.preproc.XMLGenerator:main',
            'dbVid=kaipy.scripts.quicklook.dbVid:main',
            'dbpic=kaipy.scripts.quicklook.dbpic:main',
            'dstpic=kaipy.scripts.quicklook.dstpic:main',
            'gamerrVid=kaipy.scripts.quicklook.gamerrVid:main',
            'gamerrpic=kaipy.scripts.quicklook.gamerrpic:main',
            'gamsphVid=kaipy.scripts.quicklook.gamsphVid:main',
            'heliomovie=kaipy.scripts.quicklook.heliomovie:main',
            'heliopic=kaipy.scripts.quicklook.heliopic:main',
            'mixpic=kaipy.scripts.quicklook.mixpic:main',
            'msphpic=kaipy.scripts.quicklook.msphpic:main',
            'raijupic=kaipy.scripts.quicklook.raijupic:main',
            'rcmDataProbe=kaipy.scripts.quicklook.rcmDataProbe:main',
            'rcmpic=kaipy.scripts.quicklook.rcmpic:main',
            'remixTimeSeries=kaipy.scripts.quicklook.remixTimeSeries:main',
            'swpic=kaipy.scripts.quicklook.swpic:main',
            'vizTrj=kaipy.scripts.quicklook.vizTrj:main',
            'raijudst=kaipy.raiju.dst:main',  
            'raijum2m=kaipy.raiju.m2m:main'        
        ]
    }
)
